﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data.Linq.Mapping;
using System.Data.Linq;
using System.Data.SqlClient;

namespace AssociationOneToMany
{
    [Table( Name="Jednostka" )]
    class Jednostka
    {
        private EntitySet<Osoba> _K_Osoba;

        [Column( IsPrimaryKey=true, CanBeNull=false )]
        public int ID { get; set; }
        [Column]
        public string Nazwa { get; set; }
        [Association( Storage="_K_Osoba", OtherKey="Jednostka_ID" )]
        public EntitySet<Osoba> K_Osoba
        {
            get { return this._K_Osoba; }
            set { this._K_Osoba.Assign( value ); }
        }
    }
    [Table]
    class Osoba
    {
        private EntityRef<Jednostka> _Jednostka;

        [Column( IsPrimaryKey=true, CanBeNull=false )]
        public int ID { get; set; }
        [Column]
        public string Imie { get; set; }
        [Column]
        public string Nazwisko { get; set; }
        [Column]
        private int? Jednostka_ID { get; set; }
        [Association( Storage="_Jednostka", ThisKey="Jednostka_ID", IsForeignKey=true )]
        public Jednostka Jednostka
        {
            get { return this._Jednostka.Entity; }
            set { this._Jednostka.Entity = value; }
        }
    }
    class Program
    {
        static void Main( string[] args )
        {
            DataContext dc = new DataContext( new SqlConnection( "Data Source=.;Initial Catalog=Test;Integrated Security=True" ) );
            var jednostki = dc.GetTable<Jednostka>();
            var osoby = dc.GetTable<Osoba>();

            Console.WriteLine( jednostki.Count() );
            Console.WriteLine( osoby.Count() );

            var res =
                from o in osoby
                where o.Nazwisko.EndsWith( "03" )
                select o;

            foreach ( var o in res )
                Console.WriteLine( o.Nazwisko );

            Console.WriteLine( res.First().Jednostka.Nazwa );

            osoby.InsertOnSubmit( new Osoba { ID = 150, Imie = "J", Nazwisko = "K" } );
            dc.SubmitChanges();

            foreach ( var j in jednostki )
                foreach ( var o in j.K_Osoba )
                    Console.WriteLine( j.Nazwa + " " + o.Nazwisko );
        }
    }
}
